@@ -1,26 +1,16 @@
-# Function to check file existence and permissions
+
+#' Check file read permissions
+#' 
+#' @param file_path The path to the file to check.
+#' @return TRUE if file has read permissions, otherwise throws an error.
+#' @importFrom assertthat assert_that
+#' @keywords internal
+#' @noRd
 check_file_access <- function(file_path) {
-  if (!file.exists(file_path)) {
-    cat("Error: File does not exist:", file_path, "\n")
-    return(FALSE)
-  }
-
-  if (!file.access(file_path, 4) == 0) {
-    cat("Error: No read permission for the file:", file_path, "\n")
-    return(FALSE)
-  }
-
-  file_info <- file.info(file_path)
-  cat("File size:", file_info$size, "bytes\n")
-
-  # Add more checks here if necessary, e.g., file checksum
-
+  assert_that(file.access(file_path, 4) == 0, msg = paste("Error: No read permission for the file:", file_path))
   return(TRUE)
 }
 
-
-
-
 #' Convert a NEXRAD polar volume file to an ODIM polar volume file
 #'
 #' @inheritParams vol2bird
@@ -29,8 +19,8 @@ check_file_access <- function(file_path) {
 #'
 #' @seealso
 #' * [vol2bird_config()]
+#' @importFrom assertthat assert_that
 #' @export
-#'
 #' @examples
 #' \donttest{
 #' # define filenames
@@ -47,13 +37,11 @@ check_file_access <- function(file_path) {
 #' }
 rsl2odim <- function(file, config, pvolfile_out="", verbose=TRUE, update_config=FALSE){
   for (filename in file) {
-    assert_that(file.exists(filename))
-    cat("Checking file before processing:", filename, "\n")
     if (!file.exists(filename)) {
-      stop("Error: File does not exist: ", filename)
+      warning("Error: File does not exist: ", filename)
       }
       if (!check_file_access(filename)) {
-        stop("File access check failed for: ", filename)
+        warning("File access check failed for: ", filename)
     }
   }
   if (!are_equal(pvolfile_out, "")) {
@@ -86,3 +74,6 @@ rsl2odim <- function(file, config, pvolfile_out="", verbose=TRUE, update_config=
   processor$verbose <- verbose
   processor$rsl2odim(path.expand(file), config_instance, path.expand(pvolfile_out))
 }
+
+
+
